* VERSION 1.4
* FIRST VERSION: NOV 08, 2005
* THIS VERSION:  JUL 03, 2006
* LAST REVISOR: SOB
*
* year 2000 as base year

# delimit ;

capture log close;
clear;
set matsize 800;
set rmsg on;
set seed 1234;
set more off;

cd "$rootcafe";
log using "$rootcafe/logs/displacement-psmatch2-sample.log", replace;
adopath + "$root/%stata/ado"; 

*-----------------------------------------------;
capture program drop memuse;
program define memuse;
   qui memory;
   local memused = round(_N * `r(width)' / (1024*1024));
   local memsize = round(`r(M_total)' / (1024*1024));
   display in ye "`memused' MB of `memsize' MB allocated memory in use";
end;
*-----------------------------------------------;

/***************************/
/* make 2000 the base year */
/***************************/
local w=10; 
*foreach w of numlist 6(4)6 {; /* begin of foreach wave */

   local wplus4  = `w'+4;
   local wminus4 = `w'-4;
   use "$root\xba\FDI-worker-data\FDI-worker-total_`w'.dta" if uniform()<($rsample/100), replace;
   qui count;
   di in red "Sample size of $rsample percent sample in wave `w' is `r(N)' ";
*------------------------------------------------------------;   
   preserve;   
   keep socsecid;
   sort socsecid;
   save "$root\xba\FDI-worker-data\FDI-worker-$rsample-percent_`w'.dta", replace;
   merge socsecid using "$root\xba\FDI-worker-data\FDI-worker-total_`wminus4'.dta", sort nokeep nolabel;
   keep if _merge==3;
   drop _merge;
   save "$root\xba\FDI-worker-data\FDI-worker-$rsample-percent_`wminus4'", replace;
   restore;
*------------------------------------------------------------; 
   append using "$root\xba\FDI-worker-data\FDI-worker-$rsample-percent_`wminus4'";
   qui count;
   di in red "Sample size of $rsample percent sample in waves `wminus4' and `w' is `r(N)' ";
   memuse;
   sort socsecid;

   /* merge one of three outcomes: (1) same plant resp. left plant
                                   (2) not employed next year
                                   (3) wage growth */
                                   
   /* (1) same plant resp. left plant */
   /***********************************/
   merge socsecid using "$root\xba\FDI-worker-data\lmu_same_plant.dta", nokeep keep(sp`w'_`wplus4');
   tab _merge;
   drop _merge;
   sort socsecid;
   
   /* (2) not employed next year */
   /******************************/
   merge socsecid using "$root\xba\FDI-worker-data\lmu_present_wave.dta", nokeep keep(pw`wplus4');
   tab _merge;
   drop _merge;

   /* (3) wage growth */
   /*******************/
   *merge socsecid using "$root\xba\FDI-worker-data\lmu_dlnw.dta", nokeep keep(dlnw_`w'_`wplus4');


*}; /* end of foreach wave */

*-----------------------------------------------------------;

/* define displacement two ways */
/********************************/

/* outcome 1: displace = 1 if no longer same plant */
rename sp`w'_`wplus4' separate;
recode separate 1=0 0=1;
label var separate "Displacement = 1 if left plant until next year";


/* outcome 2: displace = 1 if not employed next year */
rename pw`wplus4' notemp;
recode notemp 1=0 0=1;
label var notemp "Displacement = 1 if out of work next year";

*--------------------------------------------------------------------------------------;

/*******************************/
/* merge FDI exposure measures */
/*******************************/
/* Note 1: Exposure measures are available for ALL the years 1996-2001 
   BUT they are based on firm structures in 2000 or 2001!!!!! */
/* Note 2: "fdinr" contains the 10-digit Crefo ID for firms in corporate trees and is the original
   FDI number for standalone FDI firms; this is the case for both the "fdinr" carried in
   the BA-bst-treated_`i'.dta files (fdinr is naturally missing in bst_`i'_sect_sel_bstnr_controls)
   and in FDI-exposure*.dta */

/* merge can be WIDE (default), i.e. by fdinr only or LONG, i.e. by fdinr AND year */
/* LONG format more suitable for Slaughter (2000) remake */
/* WIDE format more suitable for displacement probit */

*global form = "long";
global form = "wide";

if "$form" == "wide" {; /* for displacement probit */
   sort fdinr;
   merge fdinr using "$root\xba\FDI-exposure\FDI-exposure_opt1_00-wide.dta", nokeep 
               keep(fdinr expo_employmt_1999* expo_employmt_2000*
                          expo_turnover_1999* expo_turnover_2000*);
};

if "$form" == "long" {; /* for Slaughter (2000) remake */
   sort fdinr year; 
   merge fdinr year using "$root\xba\FDI-exposure\FDI-exposure_opt1_00-long.dta", nokeep 
                    keep(fdinr expo_employmt*);
};

/* may want to replace missing exposure measures (for non-FDI plants!) by zeros here: 
   currently this is done in displacement-probit.do resp.  */
drop _merge;
 
*--------------------------------------------------------------------------------------;

/********************/
/* merge Ustan data */
/********************/

sort fdinr; /* to prepare for merge with Ustan data */

/* merge crefo-fdi-concordance; reason: need 10-digit-Crefo / 6-digit-FDI correspondence 
   in order to be able to merge Ustan information */
merge fdinr using "$root\Xba\FDI-Markus-names\crefo-fdi-concordance-2000-2001", nokeep;
replace fdinr=fdinrorig if _merge==3;
drop fdinrorig _merge;   

/* merge can be LONG (default) - i.e. by fdinr AND year - or WIDE - i.e. by fdinr only */
/* LONG format more suitable for Slaughter (2000) remake */
/* WIDE format more suitable for displacement probit */

*global form = "long";
global form = "wide";

if "$form" == "wide" {;
   sort fdinr;
   merge fdinr using "$root\Xustan\ustan-fdi-match-compact-wide", nokeep
   keep(par_employmt_99 par_employmt_00 par_employmt_01
        par_fixdasst_99 par_fixdasst_00 par_fixdasst_01
        par_turnover_99 par_turnover_00 par_turnover_01
        par_liab_99     par_liab_00     par_liab_01
        par_assettot_99 par_assettot_00 par_assettot_01);
};

if "$form" == "long" {;
   sort fdinr year; 
   merge fdinr year using "$root\Xustan\ustan-fdi-match-compact-long", nokeep; 
};

*----------------------------------------------------------------------------;
   
/* gen indicator fdiustan, the dummy indicating the FDI-Ustan intersection */
/***************************************************************************/
gen fdiustan=(_merge==3);
drop _merge;

*---------------------------------------------------------------------------------------------;
* define Ustan vars fixdasst (capital stock), turnover (output) and value-added in p.c. terms ;
* par_fixdasst, par_turnover and par_valueadd are in thsd of Euros and are already deflated!! ;
* par_employment is in plain numbers, i.e. NOT in thousands !!!                               ;
*---------------------------------------------------------------------------------------------;

sum par_* if fdiustan==1;

foreach yr in 99 00 01 {;
   foreach ustanvar in fixdasst turnover {;
      gen par_`ustanvar'pc_`yr' = par_`ustanvar'_`yr' / par_employmt_`yr';
   };
   gen par_debtsh_`yr' = par_liab_`yr' / par_assettot_`yr';
};

*----------------------------------------------------------------------------;

/***********************************************************************/
/* deal with missing EXPOSURE measures stemming from non-FDI firms !!! */
/* shorten variable names                                              */
/***********************************************************************/
/* expo_`expovar' all in THOUSANDS !!! */
/***************************************/

foreach year in 1999 2000 {; /* year */
   
  foreach expovar in employmt turnover /* fixdasst */ {; /* expovar */

    /* World-wide */  
    recode expo_`expovar'_`year'  .=0;
    rename expo_`expovar'_`year'  `expovar'_`year'_WW;
    gen d_`expovar'_`year'_WW = (`expovar'_`year'_WW>0);
      
    /* region-specific */      
    foreach region in APC CEE EMU ODV OIN OWE RCA {; /* region */
      recode expo_`expovar'_`year'_`region'  .=0;
      rename expo_`expovar'_`year'_`region'  `expovar'_`year'_`region';
      gen d_`expovar'_`year'_`region' = (`expovar'_`year'_`region'>0);
    };  /* region */

  }; /* expovar */

}; /* year */

*----------------------------------------------------------------------------;
* VARIABLE DEFINITIONS;
*----------------------------------------------------------------------------;

gen age2=age*age/100;

gen wz93g8 = wz93_2dig;
recode wz93g8  1/5 = 1  10/14=2  15/37=3  40/41=4  45=5  50/52=6  65/70=7  55/64 71/93=8;
drop if wz93g8>8; /* drop strange sector codes (very few cases) */
tab wz93g8;
label define wz93g8lb 1 "Agriculture and Fishery"
                      2 "Mining"
                      3 "Manufacturing"
                      4 "Utilities"
                      5 "Construction"
                      6 "Commerce"
                      7 "Finance, Insurance, Real Estate"
                      8 "Other Services";

label values wz93g8 wz93g8lb;

xi i.wz93g8, prefix(d); /* generates sector dummies and omits the first, i.e. agriculture */
drop wz93g8;

generate manf10 = wz93_2dig;
recode manf10 0/14 38/100=.
              15/16 = 1 /* food and tobacco */
              17/19 = 2 /* textile, apparel, leather */
              20/22 = 3 /* wood and paper products */
              24    = 4 /* chemicals */
              25/26 = 5 /* non-metallic products */
              27/28 = 6 /* metallic products */
              29    = 7 /* non-electrical machinery */
              30/33 = 8 /* electronics and optical equipment */
              34/35 = 9 /* transportation equipment */
              23 36/37 = 10; /* other manufacturing */

label define manf10lb 1 "food and tobacco"
                      2 "textile, apparel, leather"
                      3 "wood and paper products"
                      4 "chemicals"
                      5 "non-metallic products"
                      6 "metallic products"
                      7 "non-electrical machinery"
                      8 "electronics and optical equipment"
                      9 "transportation equipment"
                     10 "other manufacturing";
label var manf10 manf10lb;

tsset socsecid year;

gen ln_wage=ln(wage);

gen lag_ln_wage=l.ln_wage;
gen lag_nemp=l.nemp;

*---------------------------------------------------------------------------------------------;
*-----------------------------------------------------------;
* SAMPLE SELECTION CRITERIA GOOD FOR ALL CAFE ANALYSES      ;
*-----------------------------------------------------------;

/* preliminary sample selection criteria */
keep if ln_wage!=.;

/* create balanced panel in t-1 and t */
/* essentially this creates a CROSS-SECTION in 2000 only !!! ... */
/* ... but with lagged information about past wage and past plant-level employment */
keep if lag_ln_wage!=.;
keep if lag_nemp!=.;

/* check that we really get a year 2000 cross-section only */
count if year==1999; 

*--------------------------------------------------------------------------------------------;

global workervars "age age2 ln_wage lag_ln_wage female emplminor emplother wcollar abiormore apprentice parttime";
global plantvars  "east dwz93g8_2-dwz93g8_8";
global plantsizevars "nemp lag_nemp";

tsunab nonustanvars: $workervars $plantvars $plantsizevars;
global nonustanvars "`nonustanvars'";

tsunab ustanvars: par_debtsh_* par_fixdasst* par_turnover*;
global ustanvars "`ustanvars'";

tsunab treatvars: employ* d_employ*;
global treatvars "`treatvars'";

tsunab employmtlvls99: employmt_1999_???; /* regions 3-digit code (APC, CEE etc), world-wide 2-digit (WW) */
global employmtlvls99 "`employmtlvls99'";
*global employmtlvls99 = regexr("$employmtlvls99","employmt_1999_ALL","");

/***********************************************************************/
/* delete observations with missings because pscore cannot handle them */
/***********************************************************************/

/* make sure outcomes are always defined */
/*****************************************/
keep if separate !=.;
keep if notemp !=.;

/* make sure treatment is always defined */
/*****************************************/
foreach treatvar of global treatvars {;
      keep if `treatvar'!=.;
};

/* make sure control variables are always defined */
/**************************************************/
foreach var of global nonustanvars {;
      keep if `var'!=.;
};

*-----------------------------------------------------------;

/* generate and save plant-level fixed effects from Mincer regression */
/**********************************************************************/
preserve;
keep bstnr;
duplicates drop;
sort bstnr;
save "$root\xba\FDI-worker-data\displacement-probit-bstnr-$rsample", replace;

if $plantfe==1 {; /* begin of plant-level fixed effects estimation */
   merge bstnr using "$root\xba\FDI-worker-data\FDI-worker-total_`w'.dta", nokeep;
   tab _merge;
   drop _merge;
   memuse;

   gen age2=age*age/100;
	
	gen wz93g8 = wz93_2dig;
	recode wz93g8  1/5 = 1  10/14=2  15/37=3  40/41=4  45=5  50/52=6  65/70=7  55/64 71/93=8;
	drop if wz93g8>8; /* drop strange sector codes (very few cases) */
	tab wz93g8;
	
	xi i.wz93g8, prefix(d); /* generates sector dummies and omits the first, i.e. agriculture */
	drop wz93g8;
	
	gen ln_wage=ln(wage);

   tsset, clear;
   xtreg ln_wage age age2 female emplminor emplother wcollar abiormore apprentice parttime 
                 dwz93g8_2-dwz93g8_8 east nemp, fe i(bstnr);
   predict plantfe, u;
   
   keep plantfe bstnr;
   duplicates tag plantfe, gen(samefe);
   duplicates tag bstnr, gen(sameplant);
   sum same*;
	drop same*;
   bysort bstnr: keep if _n==1;
   sort bstnr;
   save "$root\xba\FDI-worker-data\displacement-probit-sample-plant-FE", replace;
   
}; /* end of plant-level fixed effects estimation */

restore;

*-----------------------------------------------------------;

/* merge plant-level variables */
/*******************************/
memuse;
sort bstnr;
merge bstnr using "$root\xba\FDI-plant-data\FDI-plant-data_`w'_total-all.dta", nokeep keep(p_*);
tab _merge;
drop _merge;
memuse;

/* merge plant-level fixed effects */
/***********************************/
sort bstnr;
merge bstnr using "$root\xba\FDI-worker-data\displacement-probit-sample-plant-FE";
tab _merge;
drop _merge;
memuse;

save "$root\xba\FDI-worker-data\displacement-probit-worker-sample-$rsample", replace;

*-----------------------------------------------------------;

cd "$root";
log close;
